@@ -317,8 +317,7 @@ impl Decorators {
             ($method:expr, $fn_name:expr, $key_prop_value:expr) => {{
                 let fn_name = $fn_name;
                 let method = $method;
-
-                let mut folder = SuperFieldAccessFolder {
+                let mut folder = swc_ecma_visit::as_folder(SuperFieldAccessFolder {
                     class_name: &ident,
                     vars: &mut vars,
                     constructor_this_mark: None,
@@ -327,7 +326,7 @@ impl Decorators {
                     in_nested_scope: false,
                     in_injected_define_property_call: false,
                     this_alias_mark: None,
-                };
+                });
 
                 let method = method.fold_with(&mut folder);
 
